package de.fitko.fitconnect.api.domain.model.metadata.data;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;

import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

public enum DataSignatureType {

    SHA_512("sha512");

    private static final Map<String, DataSignatureType> CONSTANTS = new HashMap<>();

    static {
        for (final DataSignatureType c : values()) {
            CONSTANTS.put(c.value, c);
        }
    }

    private final String value;

    DataSignatureType(final String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    @JsonValue
    public String value() {
        return this.value;
    }

    @JsonCreator
    public static DataSignatureType fromValue(final String value) {
        final DataSignatureType constant = CONSTANTS.get(value);
        if (constant == null) {
            throw new IllegalArgumentException("Unexpected value '" + value + "'");
        }
        return constant;
    }

}
